@@ -1,4 +1,4 @@
-from capture_args import capture_args
+from .capture_args import capture_args
 from subprocess import run
 
 def maga():
